import './App.css';
import React from 'react';
import { BrowserRouter, Routes, Route } from "react-router-dom";

import Header from "./container/Header"
import Leaderboard from "./container/Leaderboard"
import Game from "./components/Game"
import About from "./components/About"

import usePollingReducer from './reducer/polling';
import useUserReducer from './reducer/user';
import useLeaderboardReducer from './reducer/leaderboard';

import useLeaderboardApi from './api/leaderboard';
import useUserApi from './api/user';

function App() {
  const pollingReducer = usePollingReducer();
  const userReducer = useUserReducer();
  const leaderboardReducer = useLeaderboardReducer();
  
  const leaderboardApi = useLeaderboardApi(leaderboardReducer);
  const userApi = useUserApi(userReducer);
  
  const leaderboard = leaderboardApi.get(pollingReducer);
  const user = userApi.get();

  return (
    <div className="App" >
      <BrowserRouter>
        <Header pollingReducer={pollingReducer} />
        <Routes>
          {/* https://stackoverflow.com/questions/40541994/multiple-path-names-for-a-same-component-in-react-router */}
          <Route path="/game" element={<Game />} />
          <Route path="/game/new" element={<Game />} />
          <Route path="/game/proposal" element={<Game />} />
          <Route path="/game/active" element={<Game />} />
          <Route path="/game/archive" element={<Game />} />
          <Route path="/leaderboard" element={<Leaderboard leaderboard={leaderboard} user={user} />} />
          <Route path="/about" element={<About />} />
        </Routes>
      </BrowserRouter>
    </div>
  )
}

export default App;
